@@ -8,6 +8,6 @@ class spent_for(RelationDefinition):
     cardinality = '?*'
     __permissions__ = {
         'read' : ('managers', 'users'),
-        'add': ('managers', RRQLExpression('S in_state ST, NOT ST name "accepted"')),
-        'delete': ('managers', RRQLExpression('S in_state ST, NOT ST name "accepted"')),
+        'add': ('managers', RRQLExpression('NOT (S in_state ST, ST name "accepted")')),
+        'delete': ('managers', RRQLExpression('NOT (S in_state ST, ST name "accepted")')),
         }
